spannertools.get_spanners_attached_to_component
===============================================

.. autofunction:: abjad.tools.spannertools.get_spanners_attached_to_component.get_spanners_attached_to_component
